@@ -9,15 +9,15 @@ from stepwise import Quantity
 from param_helpers import *
 from pytest import approx
 
-parse_schema = lambda input_name, schema={}: Schema({
-    input_name: str,
-    Optional('kwargs', default={}): with_freeze.eval,
-    **with_freeze.error_or({
-        'parsed': with_freeze.eval,
-        'converted': {str: eval},
-    }),
-    **schema,
-})
+parse_schema = [
+        cast(
+            parsed=with_freeze.eval,
+            converted=with_py.eval,
+            kwargs=with_py.eval,
+        ),
+        defaults(kwargs={}),
+        with_freeze.error_or('parsed', 'converted'),
+]
 
 @parametrize_from_file
 def test_normalize_seq(raw_seq, expected):
@@ -29,37 +29,31 @@ def test_reverse_complement():
     assert reverse_complement('ATCG') == 'CGAT'
 
 @parametrize_from_file(
-        schema=Schema({
-            'seq': str,
-            'ref': str,
-            Optional('kwargs', default={}): with_py.eval,
-            'expected': with_py.eval,
-        }),
+        schema=[
+            cast(kwargs=with_py.eval, expected=with_py.eval),
+            defaults(kwargs={}),
+        ],
 )
 def test_calc_sequence_identity(seq, ref, kwargs, expected):
     id = calc_sequence_identity(seq, ref, **kwargs)
     assert id == pytest.approx(float(expected))
 
 @parametrize_from_file(
-        schema=Schema({
-            'seq': str,
-            'ref': str,
-            Optional('kwargs', default={}): with_py.eval,
-            'expected': with_py.eval,
-        }),
+        schema=[
+            cast(kwargs=with_py.eval, expected=with_py.eval),
+            defaults(kwargs={}),
+        ],
 )
 def test_calc_sequence_identity_with_rc(seq, ref, kwargs, expected):
     id = calc_sequence_identity_with_rc(seq, ref, **kwargs)
     assert id == pytest.approx(float(expected))
 
 @parametrize_from_file(
-        schema=Schema({
-            Optional('db', default={}): dict,
-            'tag': with_py.eval,
-            **with_freeze.error_or({
-                'expected': with_py.eval(keys=True),
-            }),
-        }),
+        schema=[
+            defaults(db={}),
+            cast(tag=with_py.eval, expected=with_py.eval(keys=True)),
+            with_freeze.error_or('expected'),
+        ],
 )
 def test_check_tag(db, tag, expected, error):
     db = eval_db(db)
@@ -68,18 +62,16 @@ def test_check_tag(db, tag, expected, error):
         assert {k: m.group(k) for k, v in expected.items()} == expected
 
 @parametrize_from_file(
-        schema=Schema({
-            'bool_str': str,
-            **with_freeze.error_or({
-                'expected': eval,
-            }),
-        }),
+        schema=[
+            cast(expected=with_py.eval),
+            with_freeze.error_or('expected'),
+        ],
 )
 def test_parse_bool(bool_str, expected, error):
     with error:
         assert parse_bool(bool_str) == expected
 
-@parametrize_from_file(schema=parse_schema('time_str'))
+@parametrize_from_file(schema=parse_schema)
 def test_parse_time(time_str, kwargs, parsed, converted, error):
     with error:
         assert parse_time(time_str, **kwargs) == parsed
@@ -91,31 +83,25 @@ def test_parse_time(time_str, kwargs, parsed, converted, error):
         assert parse_time_h(time_str, **kwargs) == approx(converted['h'])
 
 @parametrize_from_file(
-        schema=Schema({
-            'given': eval,
-            'expected': str,
-        })
+        schema=cast(given=with_py.eval),
 )
 def test_format_time_s(given, expected):
     assert format_time_s(given) == expected
 
 @parametrize_from_file(
-        schema=Schema({
-            'given': eval,
-            'expected': str,
-        })
+        schema=cast(given=with_py.eval),
 )
 def test_format_time_m(given, expected):
     assert format_time_m(given) == expected
 
-@parametrize_from_file(schema=parse_schema('temp_str'))
+@parametrize_from_file(schema=parse_schema)
 def test_parse_temp(temp_str, kwargs, parsed, converted, error):
     with error:
         assert parse_temp(temp_str, **kwargs) == parsed
     with error:
         assert parse_temp_C(temp_str, **kwargs) == approx(converted['C'])
 
-@parametrize_from_file(schema=parse_schema('vol_str'))
+@parametrize_from_file(schema=parse_schema)
 def test_parse_volume(vol_str, kwargs, parsed, converted, error):
     with error:
         assert parse_volume(vol_str, **kwargs) == parsed
@@ -124,7 +110,7 @@ def test_parse_volume(vol_str, kwargs, parsed, converted, error):
     with error:
         assert parse_volume_mL(vol_str, **kwargs) == approx(converted['mL'])
 
-@parametrize_from_file(schema=parse_schema('mass_str'))
+@parametrize_from_file(schema=parse_schema)
 def test_parse_mass(mass_str, kwargs, parsed, converted, error):
     with error:
         assert parse_mass(mass_str, **kwargs) == parsed
@@ -133,7 +119,7 @@ def test_parse_mass(mass_str, kwargs, parsed, converted, error):
     with error:
         assert parse_mass_mg(mass_str, **kwargs) == approx(converted['mg'])
 
-@parametrize_from_file(schema=parse_schema('conc_str', {'mw': eval}))
+@parametrize_from_file(schema=[*parse_schema, cast(mw=with_py.eval)])
 def test_parse_conc(conc_str, mw, kwargs, parsed, converted, error):
     from itertools import combinations_with_replacement
 
@@ -162,7 +148,7 @@ def test_parse_conc(conc_str, mw, kwargs, parsed, converted, error):
                 abs=Quantity(1e-6, unit),
         )
 
-@parametrize_from_file(schema=parse_schema('size_str'))
+@parametrize_from_file(schema=parse_schema)
 def test_parse_size(size_str, kwargs, parsed, converted, error):
     with error:
         assert parse_size(size_str, **kwargs) == parsed
@@ -172,13 +158,15 @@ def test_parse_size(size_str, kwargs, parsed, converted, error):
         assert parse_size_kb(size_str, **kwargs) == converted['kb']
 
 @parametrize_from_file(
-        schema=Schema({
-            'molecule': eval,
-            Optional('default_strandedness', default='None'): eval,
-            **with_freeze.error_or({
-                'expected': eval,
-            }),
-        })
+        schema=[
+            cast(
+                molecule=with_py.eval,
+                default_strandedness=with_py.eval,
+                expected=with_py.eval,
+            ),
+            defaults(default_strandedness=None),
+            with_freeze.error_or('expected'),
+        ],
 )
 def test_parse_stranded_molecule(molecule, default_strandedness, expected, error):
     with error:
@@ -186,40 +174,38 @@ def test_parse_stranded_molecule(molecule, default_strandedness, expected, error
         assert actual == expected
 
 @parametrize_from_file(
-        schema=Schema({
-            'len': Coerce(int),
-            'molecule': eval,
-            'expected': Coerce(float),
-        }),
+        schema=cast(len=int, molecule=with_py.eval, expected=float),
 )
 def test_mw_from_length(len, molecule, expected):
     assert mw_from_length(len, molecule) == approx(expected)
 
 @parametrize_from_file(
-        schema=Schema({
-            'items': eval,
-            Optional('kwargs', default={}): {str: eval},
-            **with_freeze.error_or({
-                'expected': eval,
-            }),
-        }),
+        schema=[
+            cast(
+                items=with_py.eval,
+                kwargs=with_py.eval,
+                expected=with_py.eval,
+            ),
+            defaults(kwargs={}),
+            with_freeze.error_or('expected'),
+        ],
 )
 def test_unanimous(items, kwargs, expected, error):
     with error:
         assert unanimous(items, **kwargs) == expected
 
-@parametrize_from_file(schema=Schema({str: eval}))
+@parametrize_from_file(schema=with_py.eval)
 def test_join_lists(given, expected):
     assert join_lists(given) == expected
 
-@parametrize_from_file(schema=Schema({str: eval}))
+@parametrize_from_file(schema=with_py.eval)
 def test_join_dicts(given, expected):
     actual = join_dicts(given)
 
     assert actual == expected
     assert list(actual.keys()) == list(expected.keys())
 
-@parametrize_from_file(schema=Schema({str: eval}))
+@parametrize_from_file(schema=with_py.eval)
 def test_join_sets(given, expected):
     assert join_sets(given) == expected
 
